# Say Something

## Table of Contents

- [About](#about)

- [Usage](#usage)

## About <a name = "about"></a>

A simple text to speech impelementation.

### Installing

```
pip install densom-saysomething
```

## Usage <a name = "usage"></a>

```python
from saysomething import say

say("Hello world")
```
